@@ -7,10 +7,10 @@ pub use self::{
     triangle::Triangle,
 };
 use crate::Distance;
-use num_traits::{real::Real, Float, FloatConst, Num, One, Pow, Zero};
+use num_traits::{real::Real, Float, FloatConst, Num, One, Zero};
 use projective::Projective;
 use serde::{Deserialize, Serialize};
-use std::ops::Add;
+use std::ops::{Add, Div};
 
 mod ellipse_like;
 mod line;
@@ -37,11 +37,35 @@ where
     T::one() + T::one()
 }
 
+#[inline(always)]
+fn four<T>() -> T
+where
+    T: One + Add<Output = T>,
+{
+    T::one() + T::one() + T::one() + T::one()
+}
+
 #[inline(always)]
 fn pi<T: FloatConst>() -> T {
     T::PI()
 }
 
+#[inline(always)]
+fn half<T>(x: T) -> T
+where
+    T: One + Add<Output = T> + Div<Output = T>,
+{
+    x.div(two())
+}
+
+#[inline(always)]
+fn double<T>(x: &T) -> T
+where
+    T: Clone + Add<Output = T>,
+{
+    x.clone() + x.clone()
+}
+
 #[inline(always)]
 fn two_pi<T>() -> T
 where
