@@ -3,7 +3,7 @@ mod convert;
 
 #[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
 pub struct Polyline<T> {
-    pub points: Vec<T>,
+    pub points: Vec<Point<T>>,
     pub closed: bool,
 }
 
@@ -20,3 +20,12 @@ impl<T> Polygon<T> {
         Self { vertex: points.into_iter().map(|p| p.into()).collect() }
     }
 }
+
+impl<T> Polyline<T> {
+    pub fn new<P>(points: Vec<P>) -> Self
+    where
+        Point<T>: From<P>,
+    {
+        Self { points: points.into_iter().map(|p| p.into()).collect(), closed: true }
+    }
+}
